@@ -1082,15 +1082,14 @@ pub(super) async fn genesis_cells(
     conductor_handle: ConductorHandle,
 ) -> ConductorResult<()> {
     let cells_tasks = cell_ids_with_proofs.into_iter().map(|(cell_id, proof)| {
-        let authored_db = conductor
-            .get_or_create_authored_db(cell_id.dna_hash())
-            .map_err(|e| CellError::FailedToCreateAuthoredDb(e.into()));
-        let dht_db = conductor
-            .get_or_create_dht_db(cell_id.dna_hash())
-            .map_err(|e| CellError::FailedToCreateDhtDb(e.into()));
+        let space = conductor
+            .get_or_create_space(cell_id.dna_hash())
+            .map_err(|e| CellError::FailedToCreateDnaSpace(e.into()));
         async {
-            let authored_db = authored_db?;
-            let dht_db = dht_db?;
+            let space = space?;
+            let authored_db = space.authored_db;
+            let dht_db = space.dht_db;
+            let dht_db_cache = space.dht_query_cache;
             let conductor_handle = conductor_handle.clone();
             let cell_id_inner = cell_id.clone();
             let ribosome = conductor_handle
@@ -1102,6 +1101,7 @@ pub(super) async fn genesis_cells(
                     conductor_handle,
                     authored_db,
                     dht_db,
+                    dht_db_cache,
                     ribosome,
                     proof,
                 )
