@@ -197,7 +197,7 @@ pub mod wasm_test {
                 .unwrap();
 
         // Check alice's source chain contains the new value
-        let has_hash: bool = fresh_reader_test(alice_call_data.authored_env.clone(), |txn| {
+        let has_hash: bool = fresh_reader_test(alice_call_data.authored_db.clone(), |txn| {
             txn.query_row(
                 "SELECT EXISTS(SELECT 1 FROM DhtOp WHERE header_hash = :hash)",
                 named_params! {
@@ -248,7 +248,7 @@ pub mod wasm_test {
             .await;
 
         // Check alice's source chain contains the new value
-        let has_hash: bool = fresh_reader_test(alice.dht_env().clone(), |txn| {
+        let has_hash: bool = fresh_reader_test(alice.dht_db().clone(), |txn| {
             txn.query_row(
                 "SELECT EXISTS(SELECT 1 FROM DhtOp WHERE header_hash = :hash)",
                 named_params! {
